# November 21, 2024 - Version 1.6.1

Please update PrismStudio via

```python
pip install prismstudio --upgrade
```

or

```python
pip install prismstudio==1.6.1
```


If you prefer to use Anaconda, please install PrismStudio using command below

```bash
conda config --add channels conda-forge
conda install -c prism39 prismstudio
```


---

## Change Log
- Added LSEG ESG V2 Package to existing component ps.esg.added component ps.esg.diversity
- Added LSEG Financials Significant Developments to ps.event.summary
- Added LSEG Financials Business Descriptions to ps.company.description
- Added upload_timerange_universe
- Added upload_timeseries_universe
- Removed save_timerange_sql_as_universe
- Removed save_timeseries_sql_as_universe
- Fixed minor bugs

